(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51906,       1014]*)
(*NotebookOutlinePosition[     52564,       1037]*)
(*  CellTagsIndexPosition[     52520,       1033]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Lab #3:  Cortical contraction", "Title"],

Cell[TextData[StyleBox["Copyright (c)  2006, 2008 Kerry Kim, Garrett Odell, \
George von Dassow, and Edwin Munro\nPermission is granted to copy, distribute \
and/or modify this document under the terms of the GNU Free Documentation \
License, Version 1.2 or any later version published by the Free Software \
Foundation; with no Invariant Sections, no Front-Cover Texts, and no \
Back-Cover Texts.  A copy of the license is included in the section entitled \
\"GNU Free Documentation License\"",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"],

Cell[CellGroupData[{

Cell["Overview:", "Section"],

Cell[TextData[{
  "You will be constructing a more complex model of the cortex in an \
embryonic cell by connecting a large number of the cortex springs from the \
last lab.  The goal here is to show you we can quickly make some complex \
models out of simple parts in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that reproduce some of the dynamics we observe in cells.  \n\nYou will be \
building an oversimplified model of how a contractile tug-of-war among \
numerous randomly-oriented actomyosin bundles underlying the cortex of an \
mbryoninc ell might cause flow of the cortical layer.  This can give rise to \
anisotropic and spatially inhomogenous patterns of holes and local foci in \
the actomyosin mesh.  Any flow of the cortex could move, concentrate, or \
deplete cortically localized proteins or mRNAs of genes, which play important \
roles in activating the zygote's genes.  Also, in a blastomere whose volume \
cannot change, any active flow of the cortex must force an \
oppositely-directed flow in the interior which could move other proteins and \
gene products that influence cell determination.  The model we start in this \
lab will not account for any internal flow, and it will not allow for \
deformation of the shape of the cell, which we take to be a circle in our \
two-dimensional caricature of the real 3-D cell.\n\nThis lab will expose you \
to a more-complicated model that produces some very interesting behavior \
using simple componenets.  This notebook shows you how we build this model.  \
After it's built, you will explore its behavior, and then try to modify it to \
produce more realistic behavior.  This lab is a big step up in difficulty and \
complexity, but the payback is a more realistic (though still oversimplified) \
model that exhibits some really fascinating behavior.  Also, we have found \
the fastest and best way to really learn modeling and programming is to fully \
immerse yourself in a nontrivial project you're interested in."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Building the model:", "Section"],

Cell[CellGroupData[{

Cell["\<\
Initial Setup:  30 springs around a circular cell of circumferance \
100\
\>", "Subsection"],

Cell[TextData[{
  "Let's set up the model. We're going to make a ciricular chain of our \
cortex springs and wrap them around a circular 2-D cell.  In this exercise, \
we will live with the artifact that the number of cortical elements is fixed. \
 In real strands, actomyosin strans are dynamic and disappear and reappear. \n\
\nRecall from yesterday the differential equations for a single cortical \
spring.  If we had to chain together 30 of those in series, that would take \
too long to type by hand.  What we're going to do here is have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " help us make the system of differential equations for 30 springs.\n\n\
Let's start by specifying the circumferance of our cell to be 100 and the \
number of actomyosin strands to be 30.  We'll make these variables so we can \
rebuild our network later on if we decide to change the circumferance or the \
number of strands."
}], "Text"],

Cell[BoxData[{
    \(\(circumferance\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(nstrands = 30;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generating the equations:", "Subsection"],

Cell[TextData[{
  "Now, how are we going to go about telling ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the equations for the 30 springs, and the constraint that the 30 springs \
must have a total length equal to circumference (100 in this case)?  We could \
type out the 30 equations, but you're likely to make a mistake.  Also, if you \
wanted to change thinigs, it might be difficult.  Instead, we're going to \
construct the equations in an iterative way:"
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear[t, lengthEquations, restLengthEquations, 
        initialLengthEquations, initialRestLengthEquations, 
        totalStrandLengthEquation, \ forceEquation, 
        restEquation];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(initialLengthEquations = 
        Table[\(L[i]\)[0] == circumferance/nstrands, {i, 1, 
            nstrands}];\)\), "\[IndentingNewLine]", 
    \(initialRestLengthEquations = 
      Table[\(R[i]\)[0] \[Equal] \((1 + 0.4 \((Random[] - 0.5)\))\) 
            gamma\ circumferance\ /nstrands, {i, 1, nstrands}]; 
    restLengthEquations = 
      Table[restEquation[i], {i, 1, nstrands}];\), "\[IndentingNewLine]", 
    \(\(lengthEquations = 
        Table[lengthEquation[i], {i, 2, 
            nstrands}];\)\), "\[IndentingNewLine]", 
    \(\(totalStrandLengthEquation = {circumferance \[Equal] 
            Sum[\(L[i]\)[t], {i, 1, nstrands}]};\)\)}], "Input"],

Cell[TextData[{
  "The idea in the above is that each spring really requires us to give ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4 equations:  the force due to 2 springs pulling against each other, the \
rate at which the rest length is changing, the initial lengths of the spring, \
and the initial rest length of the spring.  Rather than make a huge list of \
120 equations, we split it up into these 4 groups, which we'll later combine \
to define the whole system.  Below, we walk through the statements above, and \
you're encouraged to see what's contained in the variables we defined.  Let's \
step through each line in the above code block."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Set the initial lengths of all springs to 1/30th of the \
circumferance\
\>", "Subsubsection"],

Cell[TextData[{
  "After the clear statement, we have a statement that says:\n\n",
  StyleBox["initialLengthEquations=Table[L[i][0]==circumferance/nstrands,{i,1,\
nstrands}];\n", "Input"],
  "\nYou can type this line and leave the semicolon off.  This just makes a \
list of 30 euqations that specifies the initial length of each spring is the \
same, and is equal to the circumference divided by the # of springs.  This \
way, we didn't have to type these 30 equations in manually."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Set the initial rest lengths of springs to slightly different \
values\
\>", "Subsubsection"],

Cell[TextData[{
  "Next, we have a similar statement:\n\n",
  StyleBox["initialRestLengthEquations=\n    Table[R[i][\n          \
0]\[Equal](1+0.4(Random[]-0.5))gamma circumferance /nstrands,{i,1,\n        \
nstrands}];\n", "Input"],
  "        \nHere, we're setting the initial rest length of each spring, but \
to a slightly differt value.  If you work through the algebra in this line, \
we're setting all rest lengths equal to ",
  StyleBox["gamma", "Input"],
  " times the initial length, with some random factor.  If all the rest \
lengths and initial lengths are equal, then nothing happens, as the system is \
in an equilibrium.  Do you think it's a stable or unstable one?  You should \
have a guess based on what you saw yesterday.  Anyway, here we perturb the \
rest lengths by up to 50% from ",
  StyleBox["gamma", "Input"],
  " times the initial length, and we're going to see how this system behaves. \
 Read the help for ",
  StyleBox["Random", "Input"],
  " to see how it works and play with it if you're unsure how its used and \
what it does."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set the rate of change in each rest length:", "Subsubsection"],

Cell[TextData[{
  "The next statement says:  \n\n",
  StyleBox["restLengthEquations=Table[restEquation[i],{i,1,nstrands}];", 
    "Input"],
  "\n\nWe've made a start at this by making a table that contains a list of \
",
  StyleBox["{restEquation[1], restEquation[2],etc}", "Input"],
  ".  We'll define the ",
  StyleBox["restEquation", "Input"],
  " function soon which actually makes the differential equation so that ",
  StyleBox["restEquation[1]", "Input"],
  " gives the differential equation for how the rest length of the first \
spring changes with time, ",
  StyleBox["restEquation[2]", "Input"],
  " gives the second, etc.  Here, we are just laying the groundwork for \
things.   "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The equations for the balance of force at the connection points \
between pairs of springs:\
\>", "Subsubsection"],

Cell[TextData[{
  "Next, we have:\n\n",
  Cell[BoxData[
      \(\(\(lengthEquations = 
          Table[lengthEquation[i], {i, 2, 
              nstrands}];\)\(\[IndentingNewLine]\)
      \)\)], "Input"],
  "\nAgain, we want to set the net force pulling on each connection point \
equal to 0, and we'll write a function called ",
  StyleBox["lengthEquation[]", "Input"],
  " that does this for each connection between springs.   Also note that \
we're actually making 29 equations, not 30 (we start at 2 then count up to \
nstrands).  We'll see why we leave out the first equation later on.  \
(Basically, it's to keep from overdefining the system because we need to work \
in the fixed circumference as a constraint)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The springs have a total length of 100", "Subsubsection"],

Cell["Finally,", "Text"],

Cell[TextData[{
  StyleBox["totalStrandLengthEquation={circumferance\[Equal]Sum[L[i][t],{i,1,\
nstrands}]};\n\n", "Input"],
  "Here's where we tell ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that the sum of all the lengths must equal circumferance.  Read the help \
documentation for ",
  StyleBox["Sum", "Input"],
  " to see how it works and play with it if you're unsure how its used and \
what it does.  "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The length of each spring is determined from the force balance at \
each connection point between pairs of springs:\
\>", "Subsection"],

Cell[TextData[{
  "Here, we define ",
  StyleBox["lengthEquation", "Input"],
  ".  This is similar to that for the cortical spring you used yesterday, but \
with a few modifications.  Again, this function returns the equation for \
connection point between the one spring (i-1) and its neighbor (spring i):"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[lengthEquation, m];\)\), "\[IndentingNewLine]", 
    \(\(lengthEquation[
          i_] := \(-elasticForce[\(L[i - 1]\)[t], \(R[i - 1]\)[t]]\)\ \  - \ 
            m\ \(L[i - 1]'\)[t]\  + \ 
            elasticForce[\(L[i]\)[t], \(R[i]\)[t]]\  + \ 
            m\ \(L[i]'\)[t] \[Equal] 0;\)\)}], "Input"],

Cell["\<\
If we rewrite the above equation in words, we get:  Force due to \
spring [i-1] + viscous drag of spring [i-1] + Force due to spring [i] + \
viscous drag of spring [i].  The formula for the viscous drag of each spring \
is easy; it's just the viscous drag value m times the rate at which the \
spring is moving.  We leave the force due to each spring as a function called \
elasticForce, which depends on the current length and the rest length, and is \
defined below:\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[elasticForce, youngsModulus];\)\), "\[IndentingNewLine]", 
    \(\(elasticForce[L_, R_]\  := \ 
        youngsModulus[R]\ \((L - R)\)/R\ ;\)\)}], "Input"],

Cell[TextData[{
  "The ",
  StyleBox["elasticForce",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function looks similar to the springs from yesterday if you look at the \
right hand side of the statement above.  The force restoring the spring is \
proportional to the relative stretch of the spring.  The constant of \
proportionality is the Young's Modulus, and can be thought of as a spring \
constant that depends on the rest length (similar to what you saw yesterday). \
 Note that elasticForce takes 2 arguments as input, the current length ",
  StyleBox["L", "Input"],
  " and the rest length ",
  StyleBox["R", "Input"],
  ".  The function for the Young's Modulus is defined below."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[youngsModulus, gamma];\)\), "\[IndentingNewLine]", 
    \(\(youngsModulus[R_]\  := \ 
        k\ \((gamma*circumferance/nstrands)\)/R;\)\)}], "Input"],

Cell[TextData[{
  "Our cortex actomyosin springs are not hardware store springs.  They are \
active springs that are continuously remodeling themselves to adapt their \
rest lengths toward some frction of their current lengths.  Furthermore, we \
can imagine that any such actomyosin strand that succeeds in contracting \
will, grow stronger (in the sense of boosting its Young's modulus) because \
shortening concentrates the same amount of actin and myosin in a smaller \
region and higher concentration of contractile machinery leads to higher \
Young's modulus.   Therefore we will assume that, as the rest length gets \
shorter, the Young's modulus gets larger.  For this exercise, we just assert \
a simple recipe for how the Young's modulus increases as the spring's rest \
length decreases.  In the formula below, ",
  StyleBox["gamma*(circumferance/nstrands)", "Input"],
  " is the rest length each spring would have if all springs had spanned an \
equal fraction of the circumference for a long time.  So, when the spring's \
rest length shortens to one-half that original rest length, then ",
  StyleBox["(gamma*circumferance/nstrands)/R ", "Input"],
  "will equal  and the spring would be twice as strong.\n\nNow that these \
functions are defined, look at the equations in ",
  StyleBox["LengthEquations", "Input"],
  ".  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " automatically updated them for you.\n\nYou might be asking, why not just \
write out the entire equation in ",
  StyleBox["lengthEquation", "Input"],
  " instead of having 2 other functions involved.  Later on, you might want \
to make some modifications to this model.  By having several functions like \
this, its easier to see the chain of reasoning (once you get used to it) AND \
to make modifications to your model.  Suppose you wanted to modify how \
Young's Modulus depends on length.  If you just used one large equation in ",
  StyleBox["lengthEquation", "Input"],
  ", you could do that, but you're more likely to make a mistake, and its \
harder to see quickly what all the terms mean.  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The rate of change in rest length:", "Subsection"],

Cell[TextData[{
  "Let's define ",
  StyleBox["restEquation", "Input"],
  ", which gives us the differential equation for how the rest length changes \
for the specified spring:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[restEquation, w, 
        minimumAllowableRestLength];\)\), "\[IndentingNewLine]", 
    \(\(restEquation[i_] = \(R[i]'\)[t]\  \[Equal] \ 
          w \((gamma\ Max[\(L[i]\)[t], minimumAllowableRestLength]\  - \ \(R[
                    i]\)[t])\);\)\)}], "Input"],

Cell[TextData[{
  "We're slightly modifying yesterday's spring again, but the basic idea \
remains the same.  The rate of change in the rest length is trying to \
approach ",
  StyleBox["gamma", "Input"],
  " times the current length.  The constant of proprtionality is ",
  StyleBox["w", "Input"],
  ", the rate at which the spring rest length relaxes. \n\nFor this model, we \
don't want the pathological case where the rest length is allowed to get \
infinitely small.  If this happened, the spring would become infinitely \
strong (recall the Young's modulus increases as rest length decreases).  By \
using ",
  StyleBox["Max[L[i]'[t],minimumAllowableRestLength]", "Input"],
  " instead of ",
  StyleBox["L[i]'[t]", "Input"],
  ", we are here imposing the condition that the springs will never get \
shorter than ",
  StyleBox["minimumAllowableRestLength", "Input"],
  ".  For this model, ,we arbitrarily set ",
  StyleBox["minumAllowableRestLength", "Input"],
  " to one tenth of the starting length."
}], "Text"],

Cell[BoxData[
    \(\(minimumAllowableRestLength\  = \  .1\ *
          circumferance/nstrands;\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model parameters:", "Section"],

Cell[CellGroupData[{

Cell["Here, we set the model parameters:", "Subsection"],

Cell[BoxData[{
    \(\(Clear[k, m, gamma, w];\)\), "\[IndentingNewLine]", 
    \(\(k = 2.0;\)\), "\[IndentingNewLine]", 
    \(\(m = 20.0;\)\), "\[IndentingNewLine]", 
    \(\(gamma = 0.85;\)\), "\[IndentingNewLine]", 
    \(\(w = 1/12.0;\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving the differential equations:", "Section"],

Cell[TextData[{
  "Before we can solve the equations, we'll use ",
  StyleBox["Join", "Input"],
  " to take the separate lists of equations and put them all together.  Read \
the help for the ",
  StyleBox["Join", "Input"],
  " function to see how to use it:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[allEquations];\)\), "\[IndentingNewLine]", 
    \(\(allEquations = 
        Join[lengthEquations, restLengthEquations, initialLengthEquations, 
          initialRestLengthEquations, 
          totalStrandLengthEquation];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Solve the system of equations:", "Subsection"],

Cell[TextData[{
  "We need to tell ",
  StyleBox["NDSolve", "Input"],
  " the names of all the dependent variables in the system.  Let's generate \
these quickly."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[dependentVariables, restLengths, 
        actualLengths];\)\), "\[IndentingNewLine]", 
    \(\(restLengths\  = \ 
        Table[\(R[i]\)[t], {i, 1, nstrands}];\)\), "\[IndentingNewLine]", 
    \(\(actualLengths\  = \ 
        Table[\(L[i]\)[t], {i, 1, nstrands}];\)\), "\[IndentingNewLine]", 
    \(dependentVariables\  = \ 
      Flatten[{restLengths, \ actualLengths}]\)}], "Input"],

Cell[TextData[{
  "Instead of using ",
  StyleBox["Join", "Input"],
  ", we use the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Flatten", "Input"],
  " to join ",
  StyleBox["restLengths", "Input"],
  " and ",
  StyleBox["actualLengths", "Input"],
  ".  Read the help for this function to figure out what happened and why it \
works.\n\nBecause of the size of the system, it takes a while for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to solve the system.  It shouldn't take more than 30 seconds or so, \
though. Using our parameter sets, we need to integrate for a long period of \
simulated time for the system to do interesting things:"
}], "Text"],

Cell[BoxData[{
    \(\(tend\  = 4000;\)\), "\[IndentingNewLine]", 
    \(\(solutions\  = \ 
        NDSolve[allEquations, \ dependentVariables, {t, 0, tend}, 
          MaxStepSize \[Rule]  .2, 
          MaxSteps \[Rule] Round[20\ tend]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of lengths and rest lengths:", "Subsection"],

Cell["\<\
Your turn:  make a plot of all the lengths versus time and all the \
rest lengths versus time.  Compare your plots to your neighbors.  Work with \
them to figure out what is different, and why?  Also, was the initial \
configuration of the system stable or unstable?  \
\>", "Text"],

Cell[BoxData[
    \(\(Plot[Evaluate[actualLengths /. solutions], {t, 0, tend}, 
        PlotRange \[Rule] {0, 20}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[Evaluate[restLengths /. solutions], {t, 0, tend}, 
        PlotRange \[Rule] {0, 20}];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualizing the system:", "Section"],

Cell["\<\
It would be nice to have a better graphical representation so we \
could compare your results to the movie.  Below, I'm going to define a \
function that draws a picture of the cell at a specified time:\
\>", "Text"],

Cell[CellGroupData[{

Cell["The nodeCoordinates function:", "Subsection"],

Cell[BoxData[{\(Clear[
        nodeCoordinates];\), "\[IndentingNewLine]", \(nodeCoordinates::usage \
= "\<Given current values of the globals nstrands, and solutions = NDSolve[. \
. . ,{t,0,tend}], nodeCoordinates[t]  makes a diagram showing the locations \
of all the nodes (to which adjacent strands springs attach) at time t. To use \
nodeCoordinates[], you must first define nstrands, and make sure you have \
successfully executed the  solutions = NDSolve[ ... ,{t,0,tend}] cell.\>";\), \
"\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(nodeCoordinates[time_]\), " ", ":=", " ", 
        RowBox[{"Block", "[", 
          
          RowBox[{\({i, j, theta, thetainc, lengths, xcoords, ycoords, 
              ringRadius, nodeLocations, nodegraphics, strandgraphics, t}\), 
            ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*The\ Block\ command\ allows\ us\ to\ \
define\ "\<local variables\>"\ which\ are\ those\ in\ the\ list\ in\ the\ lie\
\ above . \ \ These\ local\ variables\ are\ defined\ only\ within\ this\ \
block\ of\ code\ and\ are\ not\ visible\ or\ accessible\ outside\ of\ this\ \
function\ nor\ will\ they\ affect\ identically\ named\ variables\ ouside\ of\ \
this\ function . \ 
                  Note\ that\ all\ the\ commands\ in\ this\ function\ are\ \
enclosed\ within\ the\ Block*) \), "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*First\ example\ of\ the\ local\ \
variable . \ \ t\ is\ set\ to\ the\ value\ time\ only\ within\ the\ context\ \
of\ this\ function . \ \ Once\ this\ function\ exits\ t\ will\ have\ its\ \
original\ value\ *) \), "\[IndentingNewLine]", 
            
            RowBox[{\(t = time\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*Get\ the\ lengths\ of\ each\ spring\
\ at\ the\ specified\ time . \ \ Here\ we\ could\ have\ equivalently\ say\ \
Evaluate[\(actualLengths\  /. \ solutions\)\  /. \ 
                      t \[Rule] 
                        time]\ except\ that\ works\ about\ 1000\ times\ \
slower\ for\ reasons\ that\ are\ hard\ to\ \(\(explain\)\(.\)\)\ \ *) \), 
              "\[IndentingNewLine]", \(lengths\  = \ 
                Flatten[Evaluate[actualLengths\  /. \ solutions]]\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*Calculate\ the\ radius\ of\ our\ \
cell*) \), "\[IndentingNewLine]", \(ringRadius\  = \ \ N[\((1 - 
                        1/\((2\ \ nstrands - 1)\))\) 
                    circumferance/\((2.  Pi)\)]\), ";", "\[IndentingNewLine]",
               "\[IndentingNewLine]", \( (*\ 
                We' re\ going\ to\ draw\ the\ anchor\ points\ between\ \
springs\ like\ pearls\ on\ an\ oversized\ necklace . \ \ First\ we\ calculate\
\ the\ angle\ between\ successive\ anchor\ points*) \), 
              "\[IndentingNewLine]", \(thetainc\  = 
                ArcTan[lengths/ringRadius]\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ Now, \ 
                we\ calculate\ the\ angular\ position\ of\ each\ anchor\ \
point\ by\ summing\ all\ the\ angles\ previous\ to\ the\ point\ in\ question\
*) \), "\[IndentingNewLine]", \(theta\  = \ 
                Union[{0}, \ 
                  Table[Sum[thetainc[\([j]\)], {j, 1, i}], {i, 1, 
                      nstrands}]]\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                Convert\ the\ angles\ to\ positions\ in\ xy\ coordinates . \ \
\ We\ put\ the\ first\ node\ at\ the\ 3\ o' clock\ position\ *) \), 
              "\[IndentingNewLine]", \(xcoords\  = \ ringRadius\ Cos[theta]\),
               ";", "\[IndentingNewLine]", \(ycoords\  = \ 
                ringRadius\ Sin[theta]\), ";", " ", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ Make\ a\ list\ of\ all\ the\ x, \ 
                y\ coordinate\ pairs\ for\ each\ anchor\ \(\(point\)\(:\)\)\ \
*) \), "\[IndentingNewLine]", \(nodeLocations\  = \ 
                Table[{xcoords[\([j]\)], ycoords[\([j]\)]}, {j, 1, 
                    nstrands}]\), " ", ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                Draw\ a\ bunch\ of\ points\ at\ each\ anchor\ *) \), 
              "\[IndentingNewLine]", \(nodegraphics\  = \ 
                Table[Graphics[{PointSize[0.025], 
                      Point[nodeLocations[\([i]\)]]}], {i, 1, nstrands}]\), 
              ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                Draw\ the\ circular\ \(\(cell\)\(:\)\)\ *) \), 
              "\[IndentingNewLine]", \(strandgraphics\  = \ \ Graphics[
                  Circle[{0, 0}, ringRadius]]\), ";", " ", 
              StyleBox["\[IndentingNewLine]",
                "SmallText"], 
              StyleBox["\[IndentingNewLine]",
                "SmallText"], \( (*\ 
                Superimpose\ the\ points\ on\ the\ cell\ *) \), 
              StyleBox["\[IndentingNewLine]",
                "SmallText"], \(Show[{nodegraphics, strandgraphics}, 
                AspectRatio \[Rule] 1]\), ";"}]}], "\[IndentingNewLine]", 
          "]"}]}], ";"}]}], "Input"],

Cell[TextData[{
  "To use this, you need to have solved the set of equations and ptu the \
solution in ",
  StyleBox["solution", "Input"],
  ".  I've commented the code above to help you follow the logic, should you \
want to cannabalize it for your own uses later on (i.e. in later labs).  In \
general, it's a good idea to comment your code (though not as extensively as \
above) so that you, your classmates, and your instructors can follow it.  \n\n\
You can also see how to add help to your own functions.  Let's read the help \
to the function defined above:"
}], "Text"],

Cell[BoxData[
    \(\(?nodeCoordinates\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Making a movie of the cell:", "Subsection"],

Cell["\<\
Run the code below and it'll spit out a whole bunch of graphs of \
the system as time goes foreward.  You'll notice to the right that there's a \
tall blue bracket that \"Groups\" all the graphs together.  Double click on \
it and it'll collapse the graphs together into a single cell.  If you now \
click on this it'll play them as a movie.\
\>", "Text"],

Cell[BoxData[
    \(\(For[tt\  = \ 0, tt < tend, 
        tt += 100, \[IndentingNewLine]{\[IndentingNewLine]\(nodeCoordinates[
              tt];\)\[IndentingNewLine]}];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["What to do next:", "Section"],

Cell[TextData[{
  "Most of this lab has been pretty passive on your part up until now. You \
should now go out and start playing with and modifying the model.  If you're \
looking for ideas, here are some things to try:\n\nSee how parameters affect \
the dynamics of what goes on\n\nTry having randomized start lengths in \
addition to or instead of randomized rest lengths and see what happens\n\nTry \
making the forces so that some springs are weaker than others by altering \
their spring constant or Young's modulus.\n\nSee if you can modify the forces \
so that you get the system tending towards several stable focal points \
sprinkled around the cell\n\n",
  StyleBox["***See if you can modify the system so that focal points somehow \
dissipate to produce dynamic instabilities similar to what you saw in the \
movie of the egg.  This, in particular, is a difficult, but really exciting \
problem:  What do you need to add to your model to really capture lifelike \
behavior, and how do simple pieces conspire to produce this behavior?",
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "Note:  for some of the above, it may be useful to use a single spring or \
pair of springs (similar to the TugOfWarII system from yesterday) as a \
simpler test case to figure out how to get your idea into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  After you've done this, then try generalizing it so you make 30 copies \
of your modified springs."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["GNU Free Documentation License\nTo view, Double click \
on the arrow to the right (2nd vertical blue line from the right edge, the \
one with the triangle at the bottom) --->",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Section"],

Cell[TextData[StyleBox["\t\tGNU Free Documentation License\n\t\t  Version \
1.2, November 2002\n\n\n Copyright (C) 2000,2001,2002  Free Software \
Foundation, Inc.\n     51 Franklin St, Fifth Floor, Boston, MA  02110-1301  \
USA\n Everyone is permitted to copy and distribute verbatim copies\n of this \
license document, but changing it is not allowed.\n\n\n0. PREAMBLE\n\nThe \
purpose of this License is to make a manual, textbook, or other\nfunctional \
and useful document \"free\" in the sense of freedom: to\nassure everyone the \
effective freedom to copy and redistribute it,\nwith or without modifying it, \
either commercially or noncommercially.\nSecondarily, this License preserves \
for the author and publisher a way\nto get credit for their work, while not \
being considered responsible\nfor modifications made by others.\n\nThis \
License is a kind of \"copyleft\", which means that derivative\nworks of the \
document must themselves be free in the same sense.  It\ncomplements the GNU \
General Public License, which is a copyleft\nlicense designed for free \
software.\n\nWe have designed this License in order to use it for manuals for \
free\nsoftware, because free software needs free documentation: a free\n\
program should come with manuals providing the same freedoms that the\n\
software does.  But this License is not limited to software manuals;\nit can \
be used for any textual work, regardless of subject matter or\nwhether it is \
published as a printed book.  We recommend this License\nprincipally for \
works whose purpose is instruction or reference.\n\n\n1. APPLICABILITY AND \
DEFINITIONS\n\nThis License applies to any manual or other work, in any \
medium, that\ncontains a notice placed by the copyright holder saying it can \
be\ndistributed under the terms of this License.  Such a notice grants a\n\
world-wide, royalty-free license, unlimited in duration, to use that\nwork \
under the conditions stated herein.  The \"Document\", below,\nrefers to any \
such manual or work.  Any member of the public is a\nlicensee, and is \
addressed as \"you\".  You accept the license if you\ncopy, modify or \
distribute the work in a way requiring permission\nunder copyright law.\n\nA \
\"Modified Version\" of the Document means any work containing the\nDocument \
or a portion of it, either copied verbatim, or with\nmodifications and/or \
translated into another language.\n\nA \"Secondary Section\" is a named \
appendix or a front-matter section of\nthe Document that deals exclusively \
with the relationship of the\npublishers or authors of the Document to the \
Document's overall subject\n(or to related matters) and contains nothing that \
could fall directly\nwithin that overall subject.  (Thus, if the Document is \
in part a\ntextbook of mathematics, a Secondary Section may not explain any\n\
mathematics.)  The relationship could be a matter of historical\nconnection \
with the subject or with related matters, or of legal,\ncommercial, \
philosophical, ethical or political position regarding\nthem.\n\nThe \
\"Invariant Sections\" are certain Secondary Sections whose titles\nare \
designated, as being those of Invariant Sections, in the notice\nthat says \
that the Document is released under this License.  If a\nsection does not fit \
the above definition of Secondary then it is not\nallowed to be designated as \
Invariant.  The Document may contain zero\nInvariant Sections.  If the \
Document does not identify any Invariant\nSections then there are none.\n\n\
The \"Cover Texts\" are certain short passages of text that are listed,\nas \
Front-Cover Texts or Back-Cover Texts, in the notice that says that\nthe \
Document is released under this License.  A Front-Cover Text may\nbe at most \
5 words, and a Back-Cover Text may be at most 25 words.\n\nA \"Transparent\" \
copy of the Document means a machine-readable copy,\nrepresented in a format \
whose specification is available to the\ngeneral public, that is suitable for \
revising the document\nstraightforwardly with generic text editors or (for \
images composed of\npixels) generic paint programs or (for drawings) some \
widely available\ndrawing editor, and that is suitable for input to text \
formatters or\nfor automatic translation to a variety of formats suitable for \
input\nto text formatters.  A copy made in an otherwise Transparent file\n\
format whose markup, or absence of markup, has been arranged to thwart\nor \
discourage subsequent modification by readers is not Transparent.\nAn image \
format is not Transparent if used for any substantial amount\nof text.  A \
copy that is not \"Transparent\" is called \"Opaque\".\n\nExamples of \
suitable formats for Transparent copies include plain\nASCII without markup, \
Texinfo input format, LaTeX input format, SGML\nor XML using a publicly \
available DTD, and standard-conforming simple\nHTML, PostScript or PDF \
designed for human modification.  Examples of\ntransparent image formats \
include PNG, XCF and JPG.  Opaque formats\ninclude proprietary formats that \
can be read and edited only by\nproprietary word processors, SGML or XML for \
which the DTD and/or\nprocessing tools are not generally available, and the\n\
machine-generated HTML, PostScript or PDF produced by some word\nprocessors \
for output purposes only.\n\nThe \"Title Page\" means, for a printed book, \
the title page itself,\nplus such following pages as are needed to hold, \
legibly, the material\nthis License requires to appear in the title page.  \
For works in\nformats which do not have any title page as such, \"Title \
Page\" means\nthe text near the most prominent appearance of the work's \
title,\npreceding the beginning of the body of the text.\n\nA section \
\"Entitled XYZ\" means a named subunit of the Document whose\ntitle either is \
precisely XYZ or contains XYZ in parentheses following\ntext that translates \
XYZ in another language.  (Here XYZ stands for a\nspecific section name \
mentioned below, such as \"Acknowledgements\",\n\"Dedications\", \
\"Endorsements\", or \"History\".)  To \"Preserve the Title\"\nof such a \
section when you modify the Document means that it remains a\nsection \
\"Entitled XYZ\" according to this definition.\n\nThe Document may include \
Warranty Disclaimers next to the notice which\nstates that this License \
applies to the Document.  These Warranty\nDisclaimers are considered to be \
included by reference in this\nLicense, but only as regards disclaiming \
warranties: any other\nimplication that these Warranty Disclaimers may have \
is void and has\nno effect on the meaning of this License.\n\n\n2. VERBATIM \
COPYING\n\nYou may copy and distribute the Document in any medium, either\n\
commercially or noncommercially, provided that this License, the\ncopyright \
notices, and the license notice saying this License applies\nto the Document \
are reproduced in all copies, and that you add no other\nconditions \
whatsoever to those of this License.  You may not use\ntechnical measures to \
obstruct or control the reading or further\ncopying of the copies you make or \
distribute.  However, you may accept\ncompensation in exchange for copies.  \
If you distribute a large enough\nnumber of copies you must also follow the \
conditions in section 3.\n\nYou may also lend copies, under the same \
conditions stated above, and\nyou may publicly display copies.\n\n\n3. \
COPYING IN QUANTITY\n\nIf you publish printed copies (or copies in media that \
commonly have\nprinted covers) of the Document, numbering more than 100, and \
the\nDocument's license notice requires Cover Texts, you must enclose the\n\
copies in covers that carry, clearly and legibly, all these Cover\nTexts: \
Front-Cover Texts on the front cover, and Back-Cover Texts on\nthe back \
cover.  Both covers must also clearly and legibly identify\nyou as the \
publisher of these copies.  The front cover must present\nthe full title with \
all words of the title equally prominent and\nvisible.  You may add other \
material on the covers in addition.\nCopying with changes limited to the \
covers, as long as they preserve\nthe title of the Document and satisfy these \
conditions, can be treated\nas verbatim copying in other respects.\n\nIf the \
required texts for either cover are too voluminous to fit\nlegibly, you \
should put the first ones listed (as many as fit\nreasonably) on the actual \
cover, and continue the rest onto adjacent\npages.\n\nIf you publish or \
distribute Opaque copies of the Document numbering\nmore than 100, you must \
either include a machine-readable Transparent\ncopy along with each Opaque \
copy, or state in or with each Opaque copy\na computer-network location from \
which the general network-using\npublic has access to download using \
public-standard network protocols\na complete Transparent copy of the \
Document, free of added material.\nIf you use the latter option, you must \
take reasonably prudent steps,\nwhen you begin distribution of Opaque copies \
in quantity, to ensure\nthat this Transparent copy will remain thus \
accessible at the stated\nlocation until at least one year after the last \
time you distribute an\nOpaque copy (directly or through your agents or \
retailers) of that\nedition to the public.\n\nIt is requested, but not \
required, that you contact the authors of the\nDocument well before \
redistributing any large number of copies, to give\nthem a chance to provide \
you with an updated version of the Document.\n\n\n4. MODIFICATIONS\n\nYou may \
copy and distribute a Modified Version of the Document under\nthe conditions \
of sections 2 and 3 above, provided that you release\nthe Modified Version \
under precisely this License, with the Modified\nVersion filling the role of \
the Document, thus licensing distribution\nand modification of the Modified \
Version to whoever possesses a copy\nof it.  In addition, you must do these \
things in the Modified Version:\n\nA. Use in the Title Page (and on the \
covers, if any) a title distinct\n   from that of the Document, and from \
those of previous versions\n   (which should, if there were any, be listed in \
the History section\n   of the Document).  You may use the same title as a \
previous version\n   if the original publisher of that version gives \
permission.\nB. List on the Title Page, as authors, one or more persons or \
entities\n   responsible for authorship of the modifications in the Modified\n\
   Version, together with at least five of the principal authors of the\n   \
Document (all of its principal authors, if it has fewer than five),\n   \
unless they release you from this requirement.\nC. State on the Title page \
the name of the publisher of the\n   Modified Version, as the publisher.\nD. \
Preserve all the copyright notices of the Document.\nE. Add an appropriate \
copyright notice for your modifications\n   adjacent to the other copyright \
notices.\nF. Include, immediately after the copyright notices, a license \
notice\n   giving the public permission to use the Modified Version under the\
\n   terms of this License, in the form shown in the Addendum below.\nG. \
Preserve in that license notice the full lists of Invariant Sections\n   and \
required Cover Texts given in the Document's license notice.\nH. Include an \
unaltered copy of this License.\nI. Preserve the section Entitled \
\"History\", Preserve its Title, and add\n   to it an item stating at least \
the title, year, new authors, and\n   publisher of the Modified Version as \
given on the Title Page.  If\n   there is no section Entitled \"History\" in \
the Document, create one\n   stating the title, year, authors, and publisher \
of the Document as\n   given on its Title Page, then add an item describing \
the Modified\n   Version as stated in the previous sentence.\nJ. Preserve the \
network location, if any, given in the Document for\n   public access to a \
Transparent copy of the Document, and likewise\n   the network locations \
given in the Document for previous versions\n   it was based on.  These may \
be placed in the \"History\" section.\n   You may omit a network location for \
a work that was published at\n   least four years before the Document itself, \
or if the original\n   publisher of the version it refers to gives \
permission.\nK. For any section Entitled \"Acknowledgements\" or \
\"Dedications\",\n   Preserve the Title of the section, and preserve in the \
section all\n   the substance and tone of each of the contributor \
acknowledgements\n   and/or dedications given therein.\nL. Preserve all the \
Invariant Sections of the Document,\n   unaltered in their text and in their \
titles.  Section numbers\n   or the equivalent are not considered part of the \
section titles.\nM. Delete any section Entitled \"Endorsements\".  Such a \
section\n   may not be included in the Modified Version.\nN. Do not retitle \
any existing section to be Entitled \"Endorsements\"\n   or to conflict in \
title with any Invariant Section.\nO. Preserve any Warranty Disclaimers.\n\n\
If the Modified Version includes new front-matter sections or\nappendices \
that qualify as Secondary Sections and contain no material\ncopied from the \
Document, you may at your option designate some or all\nof these sections as \
invariant.  To do this, add their titles to the\nlist of Invariant Sections \
in the Modified Version's license notice.\nThese titles must be distinct from \
any other section titles.\n\nYou may add a section Entitled \"Endorsements\", \
provided it contains\nnothing but endorsements of your Modified Version by \
various\nparties--for example, statements of peer review or that the text has\
\nbeen approved by an organization as the authoritative definition of a\n\
standard.\n\nYou may add a passage of up to five words as a Front-Cover Text, \
and a\npassage of up to 25 words as a Back-Cover Text, to the end of the list\
\nof Cover Texts in the Modified Version.  Only one passage of\nFront-Cover \
Text and one of Back-Cover Text may be added by (or\nthrough arrangements \
made by) any one entity.  If the Document already\nincludes a cover text for \
the same cover, previously added by you or\nby arrangement made by the same \
entity you are acting on behalf of,\nyou may not add another; but you may \
replace the old one, on explicit\npermission from the previous publisher that \
added the old one.\n\nThe author(s) and publisher(s) of the Document do not \
by this License\ngive permission to use their names for publicity for or to \
assert or\nimply endorsement of any Modified Version.\n\n\n5. COMBINING \
DOCUMENTS\n\nYou may combine the Document with other documents released under \
this\nLicense, under the terms defined in section 4 above for modified\n\
versions, provided that you include in the combination all of the\nInvariant \
Sections of all of the original documents, unmodified, and\nlist them all as \
Invariant Sections of your combined work in its\nlicense notice, and that you \
preserve all their Warranty Disclaimers.\n\nThe combined work need only \
contain one copy of this License, and\nmultiple identical Invariant Sections \
may be replaced with a single\ncopy.  If there are multiple Invariant \
Sections with the same name but\ndifferent contents, make the title of each \
such section unique by\nadding at the end of it, in parentheses, the name of \
the original\nauthor or publisher of that section if known, or else a unique \
number.\nMake the same adjustment to the section titles in the list of\n\
Invariant Sections in the license notice of the combined work.\n\nIn the \
combination, you must combine any sections Entitled \"History\"\nin the \
various original documents, forming one section Entitled\n\"History\"; \
likewise combine any sections Entitled \"Acknowledgements\",\nand any \
sections Entitled \"Dedications\".  You must delete all sections\nEntitled \
\"Endorsements\".\n\n\n6. COLLECTIONS OF DOCUMENTS\n\nYou may make a \
collection consisting of the Document and other documents\nreleased under \
this License, and replace the individual copies of this\nLicense in the \
various documents with a single copy that is included in\nthe collection, \
provided that you follow the rules of this License for\nverbatim copying of \
each of the documents in all other respects.\n\nYou may extract a single \
document from such a collection, and distribute\nit individually under this \
License, provided you insert a copy of this\nLicense into the extracted \
document, and follow this License in all\nother respects regarding verbatim \
copying of that document.\n\n\n7. AGGREGATION WITH INDEPENDENT WORKS\n\nA \
compilation of the Document or its derivatives with other separate\nand \
independent documents or works, in or on a volume of a storage or\n\
distribution medium, is called an \"aggregate\" if the copyright\nresulting \
from the compilation is not used to limit the legal rights\nof the \
compilation's users beyond what the individual works permit.\nWhen the \
Document is included in an aggregate, this License does not\napply to the \
other works in the aggregate which are not themselves\nderivative works of \
the Document.\n\nIf the Cover Text requirement of section 3 is applicable to \
these\ncopies of the Document, then if the Document is less than one half of\n\
the entire aggregate, the Document's Cover Texts may be placed on\ncovers \
that bracket the Document within the aggregate, or the\nelectronic equivalent \
of covers if the Document is in electronic form.\nOtherwise they must appear \
on printed covers that bracket the whole\naggregate.\n\n\n8. TRANSLATION\n\n\
Translation is considered a kind of modification, so you may\ndistribute \
translations of the Document under the terms of section 4.\nReplacing \
Invariant Sections with translations requires special\npermission from their \
copyright holders, but you may include\ntranslations of some or all Invariant \
Sections in addition to the\noriginal versions of these Invariant Sections.  \
You may include a\ntranslation of this License, and all the license notices \
in the\nDocument, and any Warranty Disclaimers, provided that you also \
include\nthe original English version of this License and the original \
versions\nof those notices and disclaimers.  In case of a disagreement \
between\nthe translation and the original version of this License or a notice\
\nor disclaimer, the original version will prevail.\n\nIf a section in the \
Document is Entitled \"Acknowledgements\",\n\"Dedications\", or \"History\", \
the requirement (section 4) to Preserve\nits Title (section 1) will typically \
require changing the actual\ntitle.\n\n\n9. TERMINATION\n\nYou may not copy, \
modify, sublicense, or distribute the Document except\nas expressly provided \
for under this License.  Any other attempt to\ncopy, modify, sublicense or \
distribute the Document is void, and will\nautomatically terminate your \
rights under this License.  However,\nparties who have received copies, or \
rights, from you under this\nLicense will not have their licenses terminated \
so long as such\nparties remain in full compliance.\n\n\n10. FUTURE REVISIONS \
OF THIS LICENSE\n\nThe Free Software Foundation may publish new, revised \
versions\nof the GNU Free Documentation License from time to time.  Such new\n\
versions will be similar in spirit to the present version, but may\ndiffer in \
detail to address new problems or concerns.  See\n\
http://www.gnu.org/copyleft/.\n\nEach version of the License is given a \
distinguishing version number.\nIf the Document specifies that a particular \
numbered version of this\nLicense \"or any later version\" applies to it, you \
have the option of\nfollowing the terms and conditions either of that \
specified version or\nof any later version that has been published (not as a \
draft) by the\nFree Software Foundation.  If the Document does not specify a \
version\nnumber of this License, you may choose any version ever published \
(not\nas a draft) by the Free Software Foundation.\n\n\nADDENDUM: How to use \
this License for your documents\n\nTo use this License in a document you have \
written, include a copy of\nthe License in the document and put the following \
copyright and\nlicense notices just after the title page:\n\n    Copyright \
(c)  YEAR  YOUR NAME.\n    Permission is granted to copy, distribute and/or \
modify this document\n    under the terms of the GNU Free Documentation \
License, Version 1.2\n    or any later version published by the Free Software \
Foundation;\n    with no Invariant Sections, no Front-Cover Texts, and no \
Back-Cover Texts.\n    A copy of the license is included in the section \
entitled \"GNU\n    Free Documentation License\".\n\nIf you have Invariant \
Sections, Front-Cover Texts and Back-Cover Texts,\nreplace the \
\"with...Texts.\" line with this:\n\n    with the Invariant Sections being \
LIST THEIR TITLES, with the\n    Front-Cover Texts being LIST, and with the \
Back-Cover Texts being LIST.\n\nIf you have Invariant Sections without Cover \
Texts, or some other\ncombination of the three, merge those two alternatives \
to suit the\nsituation.\n\nIf your document contains nontrivial examples of \
program code, we\nrecommend releasing these examples in parallel under your \
choice of\nfree software license, such as the GNU General Public License,\nto \
permit their use in free software.\n",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1625}, {0, 1028}},
WindowSize->{849, 847},
WindowMargins->{{47, Automatic}, {Automatic, 2}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 46, 0, 88, "Title"],
Cell[1825, 55, 552, 8, 114, "Text"],

Cell[CellGroupData[{
Cell[2402, 67, 28, 0, 69, "Section"],
Cell[2433, 69, 2014, 29, 272, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4484, 103, 38, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[4547, 107, 102, 3, 38, "Subsection"],
Cell[4652, 112, 939, 15, 144, "Text"],
Cell[5594, 129, 115, 2, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5746, 136, 47, 0, 38, "Subsection"],
Cell[5796, 138, 488, 9, 64, "Text"],
Cell[6287, 149, 935, 18, 155, "Input"],
Cell[7225, 169, 679, 11, 80, "Text"],

Cell[CellGroupData[{
Cell[7929, 184, 104, 3, 28, "Subsubsection"],
Cell[8036, 189, 495, 8, 111, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8568, 202, 103, 3, 28, "Subsubsection"],
Cell[8674, 207, 1073, 20, 212, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9784, 232, 68, 0, 28, "Subsubsection"],
Cell[9855, 234, 704, 16, 130, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10596, 255, 124, 3, 28, "Subsubsection"],
Cell[10723, 260, 730, 15, 140, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11490, 280, 63, 0, 28, "Subsubsection"],
Cell[11556, 282, 24, 0, 30, "Text"],
Cell[11583, 284, 436, 11, 82, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12068, 301, 145, 3, 56, "Subsection"],
Cell[12216, 306, 319, 6, 47, "Text"],
Cell[12538, 314, 332, 6, 75, "Input"],
Cell[12873, 322, 492, 8, 62, "Text"],
Cell[13368, 332, 183, 3, 43, "Input"],
Cell[13554, 337, 713, 15, 81, "Text"],
Cell[14270, 354, 179, 3, 43, "Input"],
Cell[14452, 359, 2106, 34, 260, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16595, 398, 56, 0, 38, "Subsection"],
Cell[16654, 400, 190, 5, 31, "Text"],
Cell[16847, 407, 292, 5, 43, "Input"],
Cell[17142, 414, 1019, 21, 146, "Text"],
Cell[18164, 437, 110, 2, 27, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18323, 445, 36, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[18384, 449, 56, 0, 38, "Subsection"],
Cell[18443, 451, 254, 5, 91, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18746, 462, 54, 0, 69, "Section"],
Cell[18803, 464, 271, 7, 47, "Text"],
Cell[19077, 473, 265, 5, 59, "Input"],

Cell[CellGroupData[{
Cell[19367, 482, 52, 0, 38, "Subsection"],
Cell[19422, 484, 175, 5, 31, "Text"],
Cell[19600, 491, 413, 8, 75, "Input"],
Cell[20016, 501, 716, 19, 98, "Text"],
Cell[20735, 522, 255, 5, 59, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21027, 532, 56, 0, 38, "Subsection"],
Cell[21086, 534, 292, 5, 46, "Text"],
Cell[21381, 541, 130, 2, 27, "Input"],
Cell[21514, 545, 128, 2, 27, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21691, 553, 42, 0, 69, "Section"],
Cell[21736, 555, 226, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[21987, 563, 51, 0, 38, "Subsection"],
Cell[22041, 565, 5146, 84, 923, "Input"],
Cell[27190, 651, 577, 10, 95, "Text"],
Cell[27770, 663, 53, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27860, 669, 49, 0, 38, "Subsection"],
Cell[27912, 671, 365, 6, 62, "Text"],
Cell[28280, 679, 184, 3, 75, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28513, 688, 35, 0, 69, "Section"],
Cell[28551, 690, 1100, 17, 250, "Text"],
Cell[29654, 709, 397, 8, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30088, 722, 260, 4, 101, "Section"],
Cell[30351, 728, 21527, 282, 7974, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

